@@ -2,8 +2,8 @@
 # -*- coding:utf-8 -*-
 
 from ..util import it,client,util
-from terminal import green
-from ..const import IMG_ID,INS_TYPE
+from terminal import green,yellow
+from ..const import IMG_ID,INS_TYPE,CMD
 import json
 
 
@@ -91,7 +91,8 @@ def create_cluster(clusterName, image=IMG_ID, type=INS_TYPE, nodes=1, descriptio
 
 
 def trans_image(image):
-    if not image.startswith('m-'):
+
+    if not image.startswith('m-') and not image.startswith('img-'):
         raise Exception('Invalid imageId: %s' % image)
     return image
 
@@ -99,7 +100,7 @@ def trans_type(type):
     m = it.get_ins_type_map()
 
     if not m.get(type):
-        raise Exception('Invalid instanceType')
+        print(yellow("WARNING: '%s' may not be valid, type '%s it' for more" % (type, CMD)))
     return type
 
 def trans_nodes(n):
