@@ -1,7 +1,8 @@
 from ..util import config,client,oss_client
-from terminal import green,bold
+from terminal import green,bold,yellow
 from .. import const
 from ..util import it
+from ..const import CMD
 
 def all(region=None, osspath=None, locale=None, image=None, type=None, version=None,god=None):
     if not region and not osspath and not locale and not image and not type and not version and not god:
@@ -88,16 +89,19 @@ def update_type(type):
     else:
         m = config.getConfigs(config.COMMON)
 
-        itMap={}
+        itMap = {}
         arr = it.list()
         for n in arr:
-            itMap[n.get('name')]=1
+            itMap[n.get('name')] = 1
+
+        if not itMap.get(type):
+            print(yellow("WARNING: '%s' may not be valid, type '%s it' for more" % (type, CMD)))
+
+        m['defaulttype'] = type
+        config.setConfigs(config.COMMON, m)
+
+
 
-        if itMap.get(type):
-            m['defaulttype'] = type
-            config.setConfigs(config.COMMON, m)
-        else:
-            raise Exception('Invalid instanceType: %s' % type)
 
 def update_version(version):
     m = config.getConfigs(config.COMMON)
@@ -107,6 +111,7 @@ def update_version(version):
         config.removeConfig(config.COMMON, 'version')
     else:
         m['version'] = version
+
         try:
             client.check_client(m)
             config.setConfigs(config.COMMON, m)
@@ -114,7 +119,6 @@ def update_version(version):
             raise Exception('Invalid version %s' % version)
 
 
-
 def update_god(god):
     m = config.getConfigs(config.COMMON)
     god = god.strip()
