@@ -7,7 +7,7 @@ CMD = 'bcs'
 
 LOCALE_SUPPORTED = ['en', 'zh', 'zh_CN']
 
-VERSION = '1.2.8'
+VERSION = '1.2.9'
 
 
 IT = {
@@ -36,6 +36,14 @@ IT = {
             # {'cpu': 24, 'memory': 96, 'name': 'bcs.b4.5xlarge'},
         ],
         'default': 'bcs.a2.large'
+    },
+    'cn-beijing': {
+        'data': [
+            {'cpu': 4, 'memory': 8, 'name': 'bcs.a2.large'},
+            {'cpu': 8, 'memory': 16, 'name': 'bcs.a2.xlarge'},
+            {'cpu': 16, 'memory': 32, 'name': 'bcs.a2.3xlarge'}
+        ],
+        'default': 'bcs.a2.large'
     }
 }
 
@@ -49,6 +57,10 @@ IMG = {
     'cn-shenzhen': {
         'data': [],
         'default': 'm-94kl8am5i'
+    },
+    'cn-beijing': {
+        'data': [],
+        'default': 'm-251on8h21'
     }
 }
 
