@@ -8,20 +8,24 @@ import os
 
 cf = ConfigParser.ConfigParser()
 
-usr_home = os.path.expanduser('~')
-cfg_dir = os.path.join(usr_home, '.batchcompute')
-if(not os.path.exists(cfg_dir)):
-    os.makedirs(cfg_dir)
-cfg_path = os.path.join(cfg_dir, 'cliconfig')
+def get_cfg_path():
+    usr_home = os.path.expanduser('~')
+    cfg_dir = os.path.join(usr_home, '.batchcompute')
+    if(not os.path.exists(cfg_dir)):
+        os.makedirs(cfg_dir)
+    cfg_path = os.path.join(cfg_dir, 'cliconfig')
+    return cfg_path
 
 COMMON = 'common'
 
 def getConfigs(section, keys=['region','accesskeyid','accesskeysecret','osspath','locale','god',
-                              'defaultimage','defaulttype']):
+                              'defaultimage','defaulttype','version',
+                              'oss_region','oss_key','oss_id']):
     '''
     section: currently support 'common' only
     keys: array, example: ['region','accesskeyid']
     '''
+    cfg_path = get_cfg_path()
 
     if(os.path.exists(cfg_path)):
         cf.read(cfg_path)
@@ -37,7 +41,7 @@ def getConfigs(section, keys=['region','accesskeyid','accesskeysecret','osspath'
         return {}
 
 def setConfigs(section, opt):
-
+    cfg_path = get_cfg_path()
     with open(cfg_path,'w') as f:
         cf.remove_section(section)
         cf.add_section(section)
@@ -48,7 +52,7 @@ def setConfigs(section, opt):
     return False
 
 def setConfig(section, key , value):
-
+    cfg_path = get_cfg_path()
     with open(cfg_path,'w') as f:
         if section not in cf.sections():
             cf.add_section(section)
@@ -58,10 +62,15 @@ def setConfig(section, key , value):
     return False
 
 def removeConfig(section, key):
+    cfg_path = get_cfg_path()
     if(os.path.exists(cfg_path)):
         try:
             with open(cfg_path,'w') as f:
-                cf.remove_option(section, key)
+                if isinstance(key, (tuple,list)):
+                    for k in key:
+                       cf.remove_option(section, k)
+                else:
+                    cf.remove_option(section, key)
                 cf.write(f)
         except:
             pass
@@ -87,4 +96,13 @@ def getRegion():
         raise Exception('you need to login first')
 
 
+def get_oss_region():
+    m= getConfigs(COMMON, ['region','oss_region'])
+
+    region = m.get('oss_region') or m.get('region')
+    if region:
+        return region
+    else:
+        raise Exception('you need to login first')
+
 
